package cleaner

import (
	"os"
	"path/filepath"
	"strings"
	"time"

	"gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/server/logger"
)

// Due to a bug in Echo's upload via HTTPS, many files whose's names start
// with "multipart-" (e.g. multipart-147994571) may accumulate in /tmp.
// This thread deletes them to prevent saturating the system's disk space.

const (
	periodTimeInMin      = 45
	deleteOlderThanInMin = 30
)

var log = logger.GetInstance()

func isOlderThanMinutes(fi os.FileInfo, n time.Duration) bool {
	return time.Now().Sub(fi.ModTime()) > n*time.Minute
}

func cleanup() {
	dir := "/tmp"

	log.Info("Cleanup thread: run every ", periodTimeInMin, " minutes; delete uploaded files in ", dir, " last accessed more than ", deleteOlderThanInMin, " minutes ago")

	for {
		log.Debug("Cleanup thread: checking for files to delete...")
		openDir, err := os.Open(dir)
		if err != nil {
			log.Error("Cleanup thread exited with error: " + err.Error())
			return
		}
		// Retrieves all files entries in the directory (0 = all files in the directory).
		files, err := openDir.Readdir(0)
		if err != nil {
			log.Error("Cleanup thread error: " + err.Error())
		} else {
			for _, f := range files {
				if !f.IsDir() && f.Mode().IsRegular() {
					path := filepath.Join(dir, f.Name())
					if strings.HasPrefix(f.Name(), "multipart-") && isOlderThanMinutes(f, deleteOlderThanInMin) {
						if err := os.Remove(path); err != nil {
							log.Error("Cleanup thread error: " + err.Error())
						} else {
							log.Info("Cleanup thread: deleted ", path)
						}
					}
				}
			}
			openDir.Close()
		}
		time.Sleep(periodTimeInMin * time.Minute)
	}
}

func Start() {
	go cleanup()
}
