package router

import (
	"net/http"

	"gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/common/params"
	"gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/server/users"
	"github.com/labstack/echo/v4"
)

type RouterMisc struct {
	users *users.Users
}

func NewRouterMisc() *RouterMisc {
	return &RouterMisc{users.GetUsersInstance()}
}

// Obtains a new access token.
// curl --cacert ca.pem -X GET http://localhost:1077/misc/token -H "Authorization: Bearer <AccessToken>"
func (r *RouterMisc) GetNewToken(c echo.Context) error {
	// Retrieves logged user from context.
	user, err := getLoggedUser(r.users, c)
	if err != nil {
		return echo.NewHTTPError(http.StatusUnauthorized, err.Error())
	}

	token, err := createToken(user.Email)
	if err != nil {
		return echo.NewHTTPError(http.StatusInternalServerError, err.Error())
	}

	return c.JSON(http.StatusOK, params.Token{Token: token})
}

// Returns the public CA certificate required by Spice remote viewers.
// curl -X GET https://localhost:1077/vms/cert
func (r *RouterMisc) GetSpiceCertificate(c echo.Context) error {
	return c.File(conf.SpiceCert)
}
